<?php
/**
 * phpaga
 *
 * Print quotation to pdf
 *
 * Prints a quotation to a pdf file
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id: quotation_pdf.php 978 2010-03-21 20:39:05Z florian $
 *
 * Copyright (c) 2002, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

include_once("./config.php");
include_once(PHPAGA_LIBPATH."pdf.php");

phpaga_user_pageperm(PHPAGA_PERM_MANAGE_QUOTATIONS);

/* should we print our letterhead? */
if (isset ($REQUEST_DATA["letterhead"]) && ($REQUEST_DATA["letterhead"] == "1"))
    $letterhead = true;
else
    $letterhead = false;

/* quotation id */
if (isset ($REQUEST_DATA["id"]) && is_numeric ($REQUEST_DATA["id"])) {

    $quotInfo = phpaga_quotations_getinfo($REQUEST_DATA["id"]);

    if (PhPagaError::isError($quotInfo))
        $quotInfo->printMessage();
    else {

        $quotInfo = phpaga_utf8decodeArray($quotInfo);
        $cpnInfo_recipient = phpaga_companies_getInfo($quotInfo["cpn_id"]);

        if (PhPagaError::isError($cpnInfo_recipient))
            $cpnInfo_recipient->printMessage();
        else {

            if (isset($quotInfo["quot_person_recipient"]) && strlen($quotInfo["quot_person_recipient"]))
                $cpnInfo_recipient["bill_person_recipient"] = $quotInfo["quot_person_recipient"];

            $cpnInfo_recipient = phpaga_utf8decodeArray($cpnInfo_recipient);

            $pdf = new phpaga_pdf_document("quotation_".
                                           date("Y", strtotime($quotInfo["quot_date"]))."-".
                                           $quotInfo["quot_number"].".pdf");

            $pdf->add_quotation($quotInfo, array("recipient" => $cpnInfo_recipient,
                                                 "letterhead" => $letterhead));

            $pdf->spitout();
        }
    }
}
else
    phpaga_error(PHPAGA_ERR_INVALID_QUOTATIONID);

?>