<?php
/**
 * phpaga
 *
 * billing plugin
 *
 * This file is a reference implementation and can be used as
 * an inspiration to create new plugins.
 *
 * This plugin contains the necessary routines to calculate a bill for:
 *
 * Liberi professionisti / ditte individuali (Italy)
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id: ita_liberoprof.php 954 2009-03-16 17:19:15Z mkimmick $
 *
 * Copyright (c) 2002, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Calculates the amount to be paid based on a startsum according to the
 * specified rules. Returns also an array containing all the documented
 * steps for this kind of billing method.
 *
 * @param real   $startsum  Start amount as base of calculation
 * @param int    $curr_id   Currency-ID
 * @param real   $endsum    The calculated amount to be paid
 * @param array  $details   Billing details
 *
 * @return void
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @since phpaga 0.1
 */

function phpaga_bill_calculate ($startsum, $curr_id = "",
				&$endsum, &$details, $paymentsum=0, $feesum=0)
{
    $details = new phpaga_bill_details ($curr_id);
    $endsum = 0;

    $inps = 0;
    $imponibile = 0;
    $iva = 0;
    $irpef = 0;

    /* 4% INPS/NISF */
    $inps = $startsum * 0.04;

    /* imponibile */
    $imponibile = $startsum + $inps;

    /* IVA 20 % */
    $iva = $imponibile * 0.2;

    /* IRPEF 20 % */
    $irpef = $imponibile * 0.2;

    /* end sum */
    $endsum = $imponibile + $iva - $irpef;

    $details->add_detail ("Honorar", $startsum);
    $details->add_detail ("4% INPS/NISF Art. 4 DL 28.3.96 n 166", $inps);
    $details->add_separator ();
    $details->add_detail ("Besteuerbarer Betrag", $imponibile);
    $details->add_detail ("Mehrwertsteuer 20%", $iva);
    $details->add_separator ();
    $details->add_detail ("Gesamtsumme", $imponibile + $iva);
    $details->add_detail ("- Steuerrückbehalt 20%", $irpef);
    $details->add_separator ();

    /* Add Latefees to bill details */
    if (is_numeric($feesum) && ($feesum > 0)) {
        $details->add_fee_detail(_("+ Late Fees"), $feesum);
    }

    /* Add Payments to bill details */
    if (is_numeric($paymentsum) && ($paymentsum > 0)) {
        $details->add_payment_detail(_("- Payments"), $paymentsum);
        $details->add_separator ();
    } else {
        $details->add_separator ();
    }


    $details->add_detail ("Guthaben", $endsum-$paymentsum+$feesum);
}

?>
