<?php
/**
 * phpaga
 *
 * billing plugin
 *
 * This file is a reference implementation and can be used as
 * an inspiration to create new plugins. You may prefer looking at
 * one of the other reference implementations as this one is too
 * basic.
 *
 * This plugin contains the necessary routines to calculate a bill for:
 *
 * No taxes.
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @author Michael Kimmick <support@nichewares.com>
 * @version $Id: notaxes.php 954 2009-03-16 17:19:15Z mkimmick $
 *
 * Copyright (c) 2002, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Calculates amount for an invoice when no taxes apply.
 * (Tell me what country that applies to!).
 *
 * @param real   $startsum  Start amount as base of calculation
 * @param int    $curr_id   Currency-ID
 * @param real   $endsum    The calculated amount to be paid
 * @param array  $details   Billing details
 * @param real	 $paymentsum	Sum of payments
 * @param real	 $feesum	Sum of late fees
 *
 * @return void
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @since phpaga 0.1
 */

function phpaga_bill_calculate ($startsum, $curr_id = "",
                                &$endsum, &$details, $expensesum = 0, $paymentsum=0, $feesum=0)
{
    $details = new phpaga_bill_details ($curr_id);

    $endsum = 0;

    /* end sum */
    $preendsum = sprintf ("%.2f", $startsum);
    $endsum = $preendsum + $expensesum;

    /* Time and Material */
    $details->add_detail(_("Time and Materials"), $startsum);

    if (is_numeric($expensesum) && ($expensesum > 0)) {
        /*$details->add_detail(_("Subtotal"), $preendsum); */
        $details->add_detail(_("+ Reimbursable expenses"), $expensesum);
    }

    /* Add Latefees to bill details */
    if (is_numeric($feesum) && ($feesum > 0)) {
	$details->add_fee_detail(_("+ Late Fees"), $feesum);
    }

    /* Add Payments to bill details */
    if (is_numeric($paymentsum) && ($paymentsum > 0)) {
        $details->add_payment_detail(_("- Payments"), $paymentsum);
	$details->add_separator ();
    } else {
        $details->add_separator ();
    }


    $details->add_detail (_("Balance Due"), $endsum-$paymentsum+$feesum);
}

?>
